aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRichard Henderson <rth@cygnus.com>1998-04-27 16:00:10 -0700
committerRichard Henderson <rth@gcc.gnu.org>1998-04-27 16:00:10 -0700
commit1052e6e6802273fe9fa1a169d92338d47bcd2208 (patch)
tree642409cf905d2ab9a00c095d22398fa5b75fc254
parent70e1ce21e5e35bfad92affd8c23a66fe53ed13aa (diff)
downloadgcc-1052e6e6802273fe9fa1a169d92338d47bcd2208.zip
gcc-1052e6e6802273fe9fa1a169d92338d47bcd2208.tar.gz
gcc-1052e6e6802273fe9fa1a169d92338d47bcd2208.tar.bz2
Bounce the ftnint argument through a local time_t.
From-SVN: r19460
-rw-r--r--libf2c/ChangeLog.egcs1
-rw-r--r--libf2c/libU77/gmtime_.c9
2 files changed, 6 insertions, 4 deletions
diff --git a/libf2c/ChangeLog.egcs b/libf2c/ChangeLog.egcs
index 81116da..5d3f369 100644
--- a/libf2c/ChangeLog.egcs
+++ b/libf2c/ChangeLog.egcs
@@ -1,6 +1,7 @@
Mon Apr 27 22:52:31 1998 Richard Henderson <rth@cygnus.com>
* libU77/ltime_.c: Bounce the ftnint argument through a local time_t.
+ * libU77/gmtime_.c: Likewise.
Sun Apr 26 18:07:56 1998 Richard Henderson <rth@cygnus.com>
diff --git a/libf2c/libU77/gmtime_.c b/libf2c/libU77/gmtime_.c
index 5f6f8ec..63ad871 100644
--- a/libf2c/libU77/gmtime_.c
+++ b/libf2c/libU77/gmtime_.c
@@ -33,14 +33,15 @@ Boston, MA 02111-1307, USA. */
#include "f2c.h"
#ifdef KR_headers
-/* Subroutine */ int G77_gmtime_0 (stime, tarray)
- integer *stime, tarray[9];
+/* Subroutine */ int G77_gmtime_0 (xstime, tarray)
+ integer *xstime, tarray[9];
#else
/* Subroutine */ int G77_gmtime_0 (const integer * stime, integer tarray[9])
#endif
{
struct tm *lt;
- lt = gmtime ((time_t *) stime);
+ time_t stime = *xstime;
+ lt = gmtime (&stime);
tarray[0] = lt->tm_sec;
tarray[1] = lt->tm_min;
tarray[2] = lt->tm_hour;
@@ -33,14 +33,15 @@ Boston, MA 02111-1307, USA. */
#else
-/* Subroutine */ int G77_gmtime_0 (const integer * stime, integer tarray[9])
+/* Subroutine */ int G77_gmtime_0 (const integer * xstime, integer tarray[9])
#endif
{